@@ -21,8 +21,10 @@
 
 #include <QDebug>
 
-#define NUM_PILE 8
-#define NUM_DECK 9
+namespace {
+constexpr auto NUM_PILE = 8;
+constexpr auto NUM_DECK = 9;
+}
 
 #define PRINT 0
 
@@ -548,7 +550,6 @@ int FortyeightSolver::getOuts()
 FortyeightSolver::FortyeightSolver(const Fortyeight *dealer)
     : Solver()
 {
-    setNumberPiles( 10 );
     deal = dealer;
 }
 
@@ -626,7 +627,7 @@ MoveHint FortyeightSolver::translateMove( const MOVE &m )
 {
     if ( m.from == NUM_DECK || m.to == NUM_DECK )
         return MoveHint();
-    PatPile *frompile = 0;
+    PatPile *frompile = nullptr;
     if ( m.from < 8 )
         frompile = deal->stack[m.from];
     else
